translate.filters.checks.TranslationChecker

Package translate :: Package filters :: Module checks :: Class TranslationChecker |
[hide private]
[frames] | no frames]

# Class TranslationChecker

source code

A checker that passes source and target strings to the checks, not the whole unit.

This provides some speedup and simplifies testing.

Instance Methods | [hide private]
__init__(self, checkerconfig=None, excludefilters=None, limitfilters=None, errorhandler=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
run_test(self, test, unit) Runs the given test on the given unit. | source code
run_filters(self, unit) Do some optimisation by caching some data of the unit for the benefit of run_test(). | source code
Inherited from `UnitChecker`: `filteraccelerators`, `filteraccelerators_by_list`, `filtervariables`, `filterwordswithpunctuation`, `filterxml`, `getfilters`, `removevariables`, `setconfig`, `setsuggestionstore` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `UnitChecker`: `preconditions`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, checkerconfig=None, excludefilters=None, limitfilters=None, errorhandler=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### run_test(self, test, unit) | source code
Runs the given test on the given unit. Note that this can raise a FilterFailure as part of normal operation. Overrides: UnitChecker.run_test

### run_filters(self, unit) | source code
Do some optimisation by caching some data of the unit for the benefit of run_test(). Overrides: UnitChecker.run_filters